@@ -140,6 +140,8 @@ class BaseFHIR():
             return None
         if type(jsondict) is dict and jsondict['resourceType'] == 'Patient':
             return PatientFHIR(patient_resource_dict=jsondict)
+        if type(jsondict) is dict and jsondict['resourceType'] == 'Parameter':
+            return ParameterFHIR(resource=jsondict)
         elif type(jsondict) is dict and jsondict['resourceType'] == 'Bundle':
             return BundleFHIR(resource=jsondict)
         elif type(jsondict) is dict and jsondict['resourceType'] == 'Immunization':
@@ -154,6 +156,26 @@ class BaseFHIR():
             return LocationFHIR(resource=jsondict)
         else:
             return self.get_model_from_json(jsondict=jsondict)
+    
+    def is_visitor(self, resource):
+        if resource is None:
+            return False
+        
+        if (type(resource) is ParameterFHIR or 
+            type(resource) is PatientFHIR or 
+            type(resource) is BundleFHIR or
+            type(resource) is ImmunizationFHIR or
+            type(resource) is OperationOutcomeFHIR or
+            type(resource) is ConditionFHIR or
+            type(resource) is OrganizationFHIR or
+            type(resource) is LocationFHIR):
+            return True
+        return False
+
+    def get_model_from_visitor(self, resource):
+        if self.is_visitor(resource=resource):
+            return resource.fhir_resource
+        return None
 
 class ConditionFHIR(BaseFHIR):
     resource_type = "Condition"
@@ -348,6 +370,8 @@ class ParameterFHIR(BaseFHIR):
         parameter.name=name
         if type(resource) is dict:
             parameter.resrouce = self.get_model_from_json(jsondict=resource)
+        elif self.is_visitor(resource=resource):
+            parameter.resource = self.get_model_from_visitor(resource=resource)
         else:
             parameter.resource = resource
         if self.fhir_resource.parameter is None:
